@@ -3,6 +3,8 @@ package Math::FFT;
 use strict;
 use warnings;
 
+use 5.008;
+
 use vars qw($VERSION @ISA);
 require DynaLoader;
 
@@ -12,7 +14,7 @@ require DynaLoader;
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
-$VERSION = '1.31';
+$VERSION = '1.32';
 
 bootstrap Math::FFT $VERSION;
 
@@ -367,6 +369,9 @@ sub deconvlv {
     return $convlv;
 }
 
+{
+
+    my $PI2 = 2 * 4.0 * atan2(1,1);
 sub spctrm {
     my ($self, %args) = @_;
     my %accept = map {$_ => 1} qw(window segments number overlap);
@@ -385,25 +390,24 @@ sub spctrm {
     my $d;
     my $n2 = 0;
     my $spctrm = [];
-    my $win_sub = {
-        'hamm' => sub {
+    my $win_sub = do {
+        my $h = sub {
             my ($j, $n) = @_;
-            my $pi = 4.0*atan2(1,1);
-            return (1 - cos(2*$pi*$j/$n))/2;
-        },
-        'hann' => sub {
-            my ($j, $n) = @_;
-            my $pi = 4.0*atan2(1,1);
-            return (1 - cos(2*$pi*$j/$n))/2;
-        },
-        'welch' => sub {
-            my ($j, $n) = @_;
-            return 1 - 4*($j-$n/2)*($j-$n/2)/$n/$n;
-        },
-        'bartlett' => sub {
-            my ($j, $n) = @_;
-            return 1 - abs(2*($j-$n/2)/$n);
-        },
+            return (1 - cos($PI2*$j/$n))/2;
+        };
+
+        +{
+            'hamm' => $h,
+            'hann' => $h,
+            'welch' => sub {
+                my ($j, $n) = @_;
+                return 1 - 4*($j-$n/2)*($j-$n/2)/$n/$n;
+            },
+            'bartlett' => sub {
+                my ($j, $n) = @_;
+                return 1 - abs(2*($j-$n/2)/$n);
+            },
+        }
     };
     if (not $args{segments} or ($args{segments} == 1 and not $args{number})) {
         die "data size ($n) must be an integer power of 2" unless _check_n($n);
@@ -480,6 +484,7 @@ sub spctrm {
     }
     return $spctrm;
 }
+}
 
 sub mean {
     my $self = shift;
@@ -599,7 +604,7 @@ Math::FFT - Perl module to calculate Fast Fourier Transforms
 
 =head1 VERSION
 
-version 1.31
+version 1.32
 
 =head1 SYNOPSIS
 
